Structs
- ApiMetadata
- Metadata about the API
- Bitmask
Def - Bitmask definition - similar to enum but for bitflags
- Callback
Def - Callback definition
- Callback
Function Def - Callback function definition
- Callback
Info Def - Callback info definition
- Constant
Def - Constant definition
- DawnApi
- The root structure of dawn.json
- Dawn
Json Parser - EnumDef
- Enum definition
- Enum
Value Def - An enum or bitmask value
- Extension
- Function
Def - Function definition
- Function
Pointer Def - Function pointer definition
- Method
Def - A method on an object
- Name
- Native
Type - Native type definition
- Object
Def - Object definition (like WebGPU handles)
- Record
Member - A record member (used in function arguments, struct members, etc.)
- Structure
Def - Structure definition
- Typedef
Def - Typedef definition
Enums
- Annotation
- Definition
- A definition can be one of many types
- Extensible
Type - Extensible type for structures - can be boolean or directional string Represents the extensible field which can be either a boolean or a direction string
- Length
Value - Represents the length field which can be either a string (field reference) or a number (literal size)
- Return
Type - Represents the returns field which can be either a simple string or an object with type and optional fields