pub enum ExtensibleType {
Direction(String),
Bool(bool),
}Expand description
Extensible type for structures - can be boolean or directional string Represents the extensible field which can be either a boolean or a direction string
Variants
Implementations
Sourceimpl ExtensibleType
impl ExtensibleType
pub fn extensible(&self) -> bool