Module parser

Module parser 

Structs

ApiMetadata
Metadata about the API
BitmaskDef
Bitmask definition - similar to enum but for bitflags
CallbackDef
Callback definition
CallbackFunctionDef
Callback function definition
CallbackInfoDef
Callback info definition
ConstantDef
Constant definition
DawnApi
The root structure of dawn.json
DawnJsonParser
EnumDef
Enum definition
EnumValueDef
An enum or bitmask value
Extension
FunctionDef
Function definition
FunctionPointerDef
Function pointer definition
MethodDef
A method on an object
Name
NativeType
Native type definition
ObjectDef
Object definition (like WebGPU handles)
RecordMember
A record member (used in function arguments, struct members, etc.)
StructureDef
Structure definition
TypedefDef
Typedef definition

Enums

Annotation
Definition
A definition can be one of many types
ExtensibleType
Extensible type for structures - can be boolean or directional string Represents the extensible field which can be either a boolean or a direction string
LengthValue
Represents the length field which can be either a string (field reference) or a number (literal size)
ReturnType
Represents the returns field which can be either a simple string or an object with type and optional fields